@@ -1,17 +1,38 @@
 #!/usr/bin/env python
 
+'''
+Copyright (C) 2014 Janina Mass
+
+This program is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <http://www.gnu.org/licenses/>
+'''
+
 import sys
 import getopt
 import subprocess
 import threading
 import os
 import shutil
+import matplotlib
+#don't use X:
+matplotlib.use('Agg')
 import matplotlib.pyplot as plt
+
 import numpy
 from distutils import spawn
 #########################
 # last update:
-# Thu 08 May 2014 01:11:15 PM CEST
+# Fr 16 Mai 2014 14:25:46 CEST
 # [JMass]
 #########################
 global GAP
@@ -186,7 +207,7 @@ class FastaParser(object):
 def usage():
     print ("""
     ######################################
-    # pysickle.py
+    # pysickle.py v0.1.1
     ######################################
     usage:
         pysickle.py -f multifasta alignment
